diff --git a/web/pgadmin/utils/tests/test_versioned_template_loader.py b/web/pgadmin/utils/tests/test_versioned_template_loader.py
index 5374b878..4ba56033 100644
--- a/web/pgadmin/utils/tests/test_versioned_template_loader.py
+++ b/web/pgadmin/utils/tests/test_versioned_template_loader.py
@@ -33,34 +33,37 @@ class TestVersionedTemplateLoader(BaseTestGenerator):
     def test_get_source_returns_a_template(self):
         expected_content = "Some SQL" \
                            "\nsome more stuff on a new line\n"
-
+        # For cross platform we join the SQL path (This solves the slashes issue)
+        sql_path = os.path.join("some_feature", "sql", "9.1_plus", "some_action.sql")
         content, filename, up_to_dateness = self.loader.get_source(None, "some_feature/sql/9.1_plus/some_action.sql")
-
-        self.assertEqual(expected_content, content)
-        self.assertIn("some_feature/sql/9.1_plus/some_action.sql", filename)
+        self.assertEqual(expected_content, str(content).replace("\r",""))
+        self.assertIn(sql_path, filename)
 
     def test_get_source_when_the_version_is_9_1_returns_9_1_template(self):
         expected_content = "Some SQL" \
                            "\nsome more stuff on a new line\n"
-
+        # For cross platform we join the SQL path (This solves the slashes issue)
+        sql_path = os.path.join("some_feature", "sql", "9.1_plus", "some_action.sql")
         content, filename, up_to_dateness = self.loader.get_source(None, "some_feature/sql/#90100#/some_action.sql")
 
-        self.assertEqual(expected_content, content)
-        self.assertIn("some_feature/sql/9.1_plus/some_action.sql", filename)
+        self.assertEqual(expected_content, str(content).replace("\r",""))
+        self.assertIn(sql_path, filename)
 
     def test_get_source_when_the_version_is_9_3_and_there_are_templates_for_9_2_and_9_1_returns_9_2_template(self):
-
+        # For cross platform we join the SQL path (This solves the slashes issue)
+        sql_path = os.path.join("some_feature", "sql", "9.2_plus", "some_action.sql")
         content, filename, up_to_dateness = self.loader.get_source(None, "some_feature/sql/#90300#/some_action.sql")
 
-        self.assertEqual("Some 9.2 SQL", content)
-        self.assertIn("some_feature/sql/9.2_plus/some_action.sql", filename)
+        self.assertEqual("Some 9.2 SQL", str(content).replace("\r",""))
+        self.assertIn(sql_path, filename)
 
     def test_get_source_when_the_version_is_9_0_and_there_are_templates_for_9_1_and_9_2_returns_default_template(self):
-
+        # For cross platform we join the SQL path (This solves the slashes issue)
+        sql_path = os.path.join("some_feature", "sql", "default", "some_action_with_default.sql")
         content, filename, up_to_dateness = self.loader.get_source(None, "some_feature/sql/#90000#/some_action_with_default.sql")
 
-        self.assertEqual("Some default SQL", content)
-        self.assertIn("some_feature/sql/default/some_action_with_default.sql", filename)
+        self.assertEqual("Some default SQL", str(content).replace("\r",""))
+        self.assertIn(sql_path, filename)
 
     def test_raise_not_found_exception_when_postgres_version_less_than_all_available_sql_templates(self):
 
diff --git a/web/regression/feature_utils/app_starter.py b/web/regression/feature_utils/app_starter.py
index b03f2a94..98762ca2 100644
--- a/web/regression/feature_utils/app_starter.py
+++ b/web/regression/feature_utils/app_starter.py
@@ -27,13 +27,11 @@ class AppStarter:
         random_server_port = str(random.randint(10000, 65535))
         env = {
             "PGADMIN_PORT": random_server_port,
-            "SQLITE_PATH": self.app_config.TEST_SQLITE_PATH
+            "SQLITE_PATH": str(self.app_config.TEST_SQLITE_PATH)
                }
         env.update(os.environ)
-
         self.pgadmin_process = subprocess.Popen(["python", "pgAdmin4.py"],
                                                 shell=False,
-                                                preexec_fn=os.setsid,
                                                 stderr=open(os.devnull, 'w'),
                                                 env=env)
 
@@ -43,4 +41,4 @@ class AppStarter:
 
     def stop_app(self):
         self.driver.quit()
-        os.killpg(os.getpgid(self.pgadmin_process.pid), signal.SIGTERM)
+        os.kill(self.pgadmin_process.pid, signal.SIGTERM)
diff --git a/web/regression/runtests.py b/web/regression/runtests.py
index 5f4a3d0c..3ab75128 100644
--- a/web/regression/runtests.py
+++ b/web/regression/runtests.py
@@ -67,10 +67,10 @@ if pgadmin_credentials:
                for item in ['login_username', 'login_password']):
             pgadmin_credentials = pgadmin_credentials[
                 'pgAdmin4_login_credentials']
-            os.environ['PGADMIN_SETUP_EMAIL'] = pgadmin_credentials[
-                'login_username']
-            os.environ['PGADMIN_SETUP_PASSWORD'] = pgadmin_credentials[
-                'login_password']
+            os.environ['PGADMIN_SETUP_EMAIL'] = str(pgadmin_credentials[
+                'login_username'])
+            os.environ['PGADMIN_SETUP_PASSWORD'] = str(pgadmin_credentials[
+                'login_password'])
 
 # Execute the setup file
 exec (open("setup.py").read())
